/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.client.proto.query.event;

import org.apache.ignite.client.proto.query.ClientMessage;
import org.apache.ignite.internal.client.proto.ClientMessagePacker;
import org.apache.ignite.internal.client.proto.ClientMessageUnpacker;
import org.apache.ignite.internal.tostring.S;

/**
 * JDBC SQL query with parameters.
 */
public class Query implements ClientMessage {
    /** Query SQL. */
    private String sql;

    /** Arguments. */
    private Object[] args;

    /**
     * Default constructor is used for serialization.
     */
    public Query() {
        // No-op.
    }

    /**
     * Constructor.
     *
     * @param sql  Query SQL.
     * @param args Arguments.
     */
    public Query(String sql, Object[] args) {
        this.sql = sql;
        this.args = args;
    }

    /**
     * Get the sql query.
     *
     * @return Query SQL string.
     */
    public String sql() {
        return sql;
    }

    /**
     * Get the sql arguments.
     *
     * @return Query arguments.
     */
    public Object[] args() {
        return args;
    }

    /** {@inheritDoc} */
    @Override
    public void writeBinary(ClientMessagePacker packer) {
        packer.packString(sql);
        packer.packObjectArray(args);
    }

    /** {@inheritDoc} */
    @Override
    public void readBinary(ClientMessageUnpacker unpacker) {
        sql = unpacker.unpackString();
        args = unpacker.unpackObjectArray();
    }

    /** {@inheritDoc} */
    @Override
    public String toString() {
        return S.toString(Query.class, this);
    }
}
